_**by Edgar Allan Poe**  
(published 1856)_

    

DURING the autumn of 18--, while on a tour through the extreme southern provinces of France, my route led me within a few miles of a certain Maison de Sante or private mad-house, about which I had heard much in Paris from my medical friends. As I had never visited a place of the kind, I thought the opportunity too good to be lost; and so proposed to my travelling companion (a gentleman with whom I had made casual acquaintance a few days before) that we should turn aside, for an hour or so, and look through the establishment. To this he objected -- pleading haste in the first place, and, in the second, a very usual horror at the sight of a lunatic. He begged me, however, not to let any mere courtesy towards himself interfere with the gratification of my curiosity, and said that he would ride on leisurely, so that I might overtake him during the day, or, at all events, during the next. As he bade me good-bye, I bethought me that there might be some difficulty in obtaining access to the premises, and mentioned my fears on this point. He replied that, in fact, unless I had personal knowledge of the superintendent, Monsieur Maillard, or some credential in the way of a letter, a difficulty might be found to exist, as the regulations of these private mad-houses were more rigid than the public hospital laws. For himself, he added, he had, some years since, made the acquaintance of Maillard, and would so far assist me as to ride up to the door and introduce me; although his feelings on the subject of lunacy would not permit of his entering the house.  
  
I thanked him, and, turning from the main road, we entered a grass-grown by-path, which, in half an hour, nearly lost itself in a dense forest, clothing the base of a mountain. Through this dank and gloomy wood we rode some two miles, when the Maison de Sante came in view. It was a fantastic chateau, much dilapidated, and indeed scarcely tenantable through age and neglect. Its aspect inspired me with absolute dread, and, checking my horse, I half resolved to turn back. I soon, however, grew ashamed of my weakness, and proceeded.  
  
As we rode up to the gate-way, I perceived it slightly open, and the visage of a man peering through. In an instant afterward, this man came forth, accosted my companion by name, shook him cordially by the hand, and begged him to alight. It was Monsieur Maillard himself. He was a portly, fine-looking gentleman of the old school, with a polished manner, and a certain air of gravity, dignity, and authority which was very impressive.  
  
My friend, having presented me, mentioned my desire to inspect the establishment, and received Monsieur Maillard's assurance that he would show me all attention, now took leave, and I saw him no more.  
  
When he had gone, the superintendent ushered me into a small and exceedingly neat parlor, containing, among other indications of refined taste, many books, drawings, pots of flowers, and musical instruments. A cheerful fire blazed upon the hearth. At a piano, singing an aria from Bellini, sat a young and very beautiful woman, who, at my entrance, paused in her song, and received me with graceful courtesy. Her voice was low, and her whole manner subdued. I thought, too, that I perceived the traces of sorrow in her countenance, which was excessively, although to my taste, not unpleasingly, pale. She was attired in deep mourning, and excited in my bosom a feeling of mingled respect, interest, and admiration.  
  
I had heard, at Paris, that the institution of Monsieur Maillard was managed upon what is vulgarly termed the "system of soothing" -- that all punishments were avoided -- that even confinement was seldom resorted to -- that the patients, while secretly watched, were left much apparent liberty, and that most of them were permitted to roam about the house and grounds in the ordinary apparel of persons in right mind.  
  
Keeping these impressions in view, I was cautious in what I said before the young lady; for I could not be sure that she was sane; and, in fact, there was a certain restless brilliancy about her eyes which half led me to imagine she was not. I confined my remarks, therefore, to general topics, and to such as I thought would not be displeasing or exciting even to a lunatic. She replied in a perfectly rational manner to all that I said; and even her original observations were marked with the soundest good sense, but a long acquaintance with the metaphysics of mania, had taught me to put no faith in such evidence of sanity, and I continued to practise, throughout the interview, the caution with which I commenced it.  
  
Presently a smart footman in livery brought in a tray with fruit, wine, and other refreshments, of which I partook, the lady soon afterward leaving the room. As she departed I turned my eyes in an inquiring manner toward my host.  
  
"No," he said, "oh, no -- a member of my family -- my niece, and a most accomplished woman."  
  
"I beg a thousand pardons for the suspicion," I replied, "but of course you will know how to excuse me. The excellent administration of your affairs here is well understood in Paris, and I thought it just possible, you know-  
  
"Yes, yes -- say no more -- or rather it is myself who should thank you for the commendable prudence you have displayed. We seldom find so much of forethought in young men; and, more than once, some unhappy contre-temps has occurred in consequence of thoughtlessness on the part of our visitors. While my former system was in operation, and my patients were permitted the privilege of roaming to and fro at will, they were often aroused to a dangerous frenzy by injudicious persons who called to inspect the house. Hence I was obliged to enforce a rigid system of exclusion; and none obtained access to the premises upon whose discretion I could not rely."  
  
"While your former system was in operation!" I said, repeating his words -- "do I understand you, then, to say that the 'soothing system' of which I have heard so much is no longer in force?"  
  
"It is now," he replied, "several weeks since we have concluded to renounce it forever."  
  
"Indeed! you astonish me!"  
  
"We found it, sir," he said, with a sigh, "absolutely necessary to return to the old usages. The danger of the soothing system was, at all times, appalling; and its advantages have been much overrated. I believe, sir, that in this house it has been given a fair trial, if ever in any. We did every thing that rational humanity could suggest. I am sorry that you could not have paid us a visit at an earlier period, that you might have judged for yourself. But I presume you are conversant with the soothing practice -- with its details."  
  
"Not altogether. What I have heard has been at third or fourth hand."  
  
"I may state the system, then, in general terms, as one in which the patients were menages-humored. We contradicted no fancies which entered the brains of the mad. On the contrary, we not only indulged but encouraged them; and many of our most permanent cures have been thus effected. There is no argument which so touches the feeble reason of the madman as the argumentum ad absurdum. We have had men, for example, who fancied themselves chickens. The cure was, to insist upon the thing as a fact -- to accuse the patient of stupidity in not sufficiently perceiving it to be a fact -- and thus to refuse him any other diet for a week than that which properly appertains to a chicken. In this manner a little corn and gravel were made to perform wonders."  
  
"But was this species of acquiescence all?"  
  
"By no means. We put much faith in amusements of a simple kind, such as music, dancing, gymnastic exercises generally, cards, certain classes of books, and so forth. We affected to treat each individual as if for some ordinary physical disorder, and the word 'lunacy' was never employed. A great point was to set each lunatic to guard the actions of all the others. To repose confidence in the understanding or discretion of a madman, is to gain him body and soul. In this way we were enabled to dispense with an expensive body of keepers."  
  
"And you had no punishments of any kind?"  
  
"None."  
  
"And you never confined your patients?"  
  
"Very rarely. Now and then, the malady of some individual growing to a crisis, or taking a sudden turn of fury, we conveyed him to a secret cell, lest his disorder should infect the rest, and there kept him until we could dismiss him to his friends -- for with the raging maniac we have nothing to do. He is usually removed to the public hospitals."  
  
"And you have now changed all this -- and you think for the better?"  
  
"Decidedly. The system had its disadvantages, and even its dangers. It is now, happily, exploded throughout all the Maisons de Sante of France."  
  
"I am very much surprised," I said, "at what you tell me; for I made sure that, at this moment, no other method of treatment for mania existed in any portion of the country."  
  
"You are young yet, my friend," replied my host, "but the time will arrive when you will learn to judge for yourself of what is going on in the world, without trusting to the gossip of others. Believe nothing you hear, and only one-half that you see. Now about our Maisons de Sante, it is clear that some ignoramus has misled you. After dinner, however, when you have sufficiently recovered from the fatigue of your ride, I will be happy to take you over the house, and introduce to you a system which, in my opinion, and in that of every one who has witnessed its operation, is incomparably the most effectual as yet devised."  
  
"Your own?" I inquired -- "one of your own invention?"  
  
"I am proud," he replied, "to acknowledge that it is -- at least in some measure."  
  
In this manner I conversed with Monsieur Maillard for an hour or two, during which he showed me the gardens and conservatories of the place.  
  
"I cannot let you see my patients," he said, "just at present. To a sensitive mind there is always more or less of the shocking in such exhibitions; and I do not wish to spoil your appetite for dinner. We will dine. I can give you some veal a la Menehoult, with cauliflowers in veloute sauce -- after that a glass of Clos de Vougeot -- then your nerves will be sufficiently steadied."  
  
At six, dinner was announced; and my host conducted me into a large salle a manger, where a very numerous company were assembled -- twenty-five or thirty in all. They were, apparently, people of rank-certainly of high breeding -- although their habiliments, I thought, were extravagantly rich, partaking somewhat too much of the ostentatious finery of the vielle cour. I noticed that at least two-thirds of these guests were ladies; and some of the latter were by no means accoutred in what a Parisian would consider good taste at the present day. Many females, for example, whose age could not have been less than seventy were bedecked with a profusion of jewelry, such as rings, bracelets, and earrings, and wore their bosoms and arms shamefully bare. I observed, too, that very few of the dresses were well made -- or, at least, that very few of them fitted the wearers. In looking about, I discovered the interesting girl to whom Monsieur Maillard had presented me in the little parlor; but my surprise was great to see her wearing a hoop and farthingale, with high-heeled shoes, and a dirty cap of Brussels lace, so much too large for her that it gave her face a ridiculously diminutive expression. When I had first seen her, she was attired, most becomingly, in deep mourning. There was an air of oddity, in short, about the dress of the whole party, which, at first, caused me to recur to my original idea of the "soothing system," and to fancy that Monsieur Maillard had been willing to deceive me until after dinner, that I might experience no uncomfortable feelings during the repast, at finding myself dining with lunatics; but I remembered having been informed, in Paris, that the southern provincialists were a peculiarly eccentric people, with a vast number of antiquated notions; and then, too, upon conversing with several members of the company, my apprehensions were immediately and fully dispelled.  
  
The dining-room itself, although perhaps sufficiently comfortable and of good dimensions, had nothing too much of elegance about it. For example, the floor was uncarpeted; in France, however, a carpet is frequently dispensed with. The windows, too, were without curtains; the shutters, being shut, were securely fastened with iron bars, applied diagonally, after the fashion of our ordinary shop-shutters. The apartment, I observed, formed, in itself, a wing of the chateau, and thus the windows were on three sides of the parallelogram, the door being at the other. There were no less than ten windows in all.  
  
The table was superbly set out. It was loaded with plate, and more than loaded with delicacies. The profusion was absolutely barbaric. There were meats enough to have feasted the Anakim. Never, in all my life, had I witnessed so lavish, so wasteful an expenditure of the good things of life. There seemed very little taste, however, in the arrangements; and my eyes, accustomed to quiet lights, were sadly offended by the prodigious glare of a multitude of wax candles, which, in silver candelabra, were deposited upon the table, and all about the room, wherever it was possible to find a place. There were several active servants in attendance; and, upon a large table, at the farther end of the apartment, were seated seven or eight people with fiddles, fifes, trombones, and a drum. These fellows annoyed me very much, at intervals, during the repast, by an infinite variety of noises, which were intended for music, and which appeared to afford much entertainment to all present, with the exception of myself.  
  
Upon the whole, I could not help thinking that there was much of the bizarre about every thing I saw -- but then the world is made up of all kinds of persons, with all modes of thought, and all sorts of conventional customs. I had travelled, too, so much, as to be quite an adept at the nil admirari; so I took my seat very coolly at the right hand of my host, and, having an excellent appetite, did justice to the good cheer set before me.  
  
The conversation, in the meantime, was spirited and general. The ladies, as usual, talked a great deal. I soon found that nearly all the company were well educated; and my host was a world of good-humored anecdote in himself. He seemed quite willing to speak of his position as superintendent of a Maison de Sante; and, indeed, the topic of lunacy was, much to my surprise, a favorite one with all present. A great many amusing stories were told, having reference to the whims of the patients.  
  
"We had a fellow here once," said a fat little gentleman, who sat at my right, -- "a fellow that fancied himself a tea-pot; and by the way, is it not especially singular how often this particular crotchet has entered the brain of the lunatic? There is scarcely an insane asylum in France which cannot supply a human tea-pot. Our gentleman was a Britannia -- ware tea-pot, and was careful to polish himself every morning with buckskin and whiting."  
  
"And then," said a tall man just opposite, "we had here, not long ago, a person who had taken it into his head that he was a donkey -- which allegorically speaking, you will say, was quite true. He was a troublesome patient; and we had much ado to keep him within bounds. For a long time he would eat nothing but thistles; but of this idea we soon cured him by insisting upon his eating nothing else. Then he was perpetually kicking out his heels-so-so-"  
  
"Mr. De Kock! I will thank you to behave yourself!" here interrupted an old lady, who sat next to the speaker. "Please keep your feet to yourself! You have spoiled my brocade! Is it necessary, pray, to illustrate a remark in so practical a style? Our friend here can surely comprehend you without all this. Upon my word, you are nearly as great a donkey as the poor unfortunate imagined himself. Your acting is very natural, as I live."  
  
"Mille pardons! Ma'm'selle!" replied Monsieur De Kock, thus addressed -- "a thousand pardons! I had no intention of offending. Ma'm'selle Laplace -- Monsieur De Kock will do himself the honor of taking wine with you."  
  
Here Monsieur De Kock bowed low, kissed his hand with much ceremony, and took wine with Ma'm'selle Laplace.  
  
"Allow me, mon ami," now said Monsieur Maillard, addressing myself, "allow me to send you a morsel of this veal a la St. Menhoult -- you will find it particularly fine."  
  
At this instant three sturdy waiters had just succeeded in depositing safely upon the table an enormous dish, or trencher, containing what I supposed to be the "monstrum horrendum, informe, ingens, cui lumen ademptum." A closer scrutiny assured me, however, that it was only a small calf roasted whole, and set upon its knees, with an apple in its mouth, as is the English fashion of dressing a hare.  
  
"Thank you, no," I replied; "to say the truth, I am not particularly partial to veal a la St. -- what is it? -- for I do not find that it altogether agrees with me. I will change my plate, however, and try some of the rabbit."  
  
There were several side-dishes on the table, containing what appeared to be the ordinary French rabbit -- a very delicious morceau, which I can recommend.  
  
"Pierre," cried the host, "change this gentleman's plate, and give him a side-piece of this rabbit au-chat."  
  
"This what?" said I.  
  
"This rabbit au-chat."  
  
"Why, thank you -- upon second thoughts, no. I will just help myself to some of the ham."  
  
There is no knowing what one eats, thought I to myself, at the tables of these people of the province. I will have none of their rabbit au-chat -- and, for the matter of that, none of their cat-au-rabbit either.  
  
"And then," said a cadaverous looking personage, near the foot of the table, taking up the thread of the conversation where it had been broken off, -- "and then, among other oddities, we had a patient, once upon a time, who very pertinaciously maintained himself to be a Cordova cheese, and went about, with a knife in his hand, soliciting his friends to try a small slice from the middle of his leg."  
  
"He was a great fool, beyond doubt," interposed some one, "but not to be compared with a certain individual whom we all know, with the exception of this strange gentleman. I mean the man who took himself for a bottle of champagne, and always went off with a pop and a fizz, in this fashion."  
  
Here the speaker, very rudely, as I thought, put his right thumb in his left cheek, withdrew it with a sound resembling the popping of a cork, and then, by a dexterous movement of the tongue upon the teeth, created a sharp hissing and fizzing, which lasted for several minutes, in imitation of the frothing of champagne. This behavior, I saw plainly, was not very pleasing to Monsieur Maillard; but that gentleman said nothing, and the conversation was resumed by a very lean little man in a big wig.  
  
"And then there was an ignoramus," said he, "who mistook himself for a frog, which, by the way, he resembled in no little degree. I wish you could have seen him, sir," -- here the speaker addressed myself -- "it would have done your heart good to see the natural airs that he put on. Sir, if that man was not a frog, I can only observe that it is a pity he was not. His croak thus -- o-o-o-o-gh -- o-o-o-o-gh! was the finest note in the world -- B flat; and when he put his elbows upon the table thus -- after taking a glass or two of wine -- and distended his mouth, thus, and rolled up his eyes, thus, and winked them with excessive rapidity, thus, why then, sir, I take it upon myself to say, positively, that you would have been lost in admiration of the genius of the man."  
  
"I have no doubt of it," I said.  
  
"And then," said somebody else, "then there was Petit Gaillard, who thought himself a pinch of snuff, and was truly distressed because he could not take himself between his own finger and thumb."  
  
"And then there was Jules Desoulieres, who was a very singular genius, indeed, and went mad with the idea that he was a pumpkin. He persecuted the cook to make him up into pies -- a thing which the cook indignantly refused to do. For my part, I am by no means sure that a pumpkin pie a la Desoulieres would not have been very capital eating indeed!"  
  
"You astonish me!" said I; and I looked inquisitively at Monsieur Maillard.  
  
"Ha! ha! ha!" said that gentleman -- "he! he! he! -- hi! hi! hi! -- ho! ho! ho! -- hu! hu! hu! hu! -- very good indeed! You must not be astonished, mon ami; our friend here is a wit -- a drole -- you must not understand him to the letter."  
  
"And then," said some other one of the party, -- "then there was Bouffon Le Grand -- another extraordinary personage in his way. He grew deranged through love, and fancied himself possessed of two heads. One of these he maintained to be the head of Cicero; the other he imagined a composite one, being Demosthenes' from the top of the forehead to the mouth, and Lord Brougham's from the mouth to the chin. It is not impossible that he was wrong; but he would have convinced you of his being in the right; for he was a man of great eloquence. He had an absolute passion for oratory, and could not refrain from display. For example, he used to leap upon the dinner-table thus, and -- and-"  
  
Here a friend, at the side of the speaker, put a hand upon his shoulder and whispered a few words in his ear, upon which he ceased talking with great suddenness, and sank back within his chair.  
  
"And then," said the friend who had whispered, "there was Boullard, the tee-totum. I call him the tee-totum because, in fact, he was seized with the droll but not altogether irrational crotchet, that he had been converted into a tee-totum. You would have roared with laughter to see him spin. He would turn round upon one heel by the hour, in this manner -- so-  
  
Here the friend whom he had just interrupted by a whisper, performed an exactly similar office for himself.  
  
"But then," cried the old lady, at the top of her voice, "your Monsieur Boullard was a madman, and a very silly madman at best; for who, allow me to ask you, ever heard of a human tee-totum? The thing is absurd. Madame Joyeuse was a more sensible person, as you know. She had a crotchet, but it was instinct with common sense, and gave pleasure to all who had the honor of her acquaintance. She found, upon mature deliberation, that, by some accident, she had been turned into a chicken-cock; but, as such, she behaved with propriety. She flapped her wings with prodigious effect -- so -- so -- and, as for her crow, it was delicious! Cock-a-doodle-doo! -- cock-a-doodle-doo! -- cock-a-doodle-de-doo-dooo-do-o-o-o-o-o-o!"  
  
"Madame Joyeuse, I will thank you to behave yourself!" here interrupted our host, very angrily. "You can either conduct yourself as a lady should do, or you can quit the table forthwith-take your choice."  
  
The lady (whom I was much astonished to hear addressed as Madame Joyeuse, after the description of Madame Joyeuse she had just given) blushed up to the eyebrows, and seemed exceedingly abashed at the reproof. She hung down her head, and said not a syllable in reply. But another and younger lady resumed the theme. It was my beautiful girl of the little parlor.  
  
"Oh, Madame Joyeuse was a fool!" she exclaimed, "but there was really much sound sense, after all, in the opinion of Eugenie Salsafette. She was a very beautiful and painfully modest young lady, who thought the ordinary mode of habiliment indecent, and wished to dress herself, always, by getting outside instead of inside of her clothes. It is a thing very easily done, after all. You have only to do so -- and then so -- so -- so -- and then so -- so -- so -- and then so -- so -- and then-  
  
"Mon dieu! Ma'm'selle Salsafette!" here cried a dozen voices at once. "What are you about? -- forbear! -- that is sufficient! -- we see, very plainly, how it is done! -- hold! hold!" and several persons were already leaping from their seats to withhold Ma'm'selle Salsafette from putting herself upon a par with the Medicean Venus, when the point was very effectually and suddenly accomplished by a series of loud screams, or yells, from some portion of the main body of the chateau.  
  
My nerves were very much affected, indeed, by these yells; but the rest of the company I really pitied. I never saw any set of reasonable people so thoroughly frightened in my life. They all grew as pale as so many corpses, and, shrinking within their seats, sat quivering and gibbering with terror, and listening for a repetition of the sound. It came again -- louder and seemingly nearer -- and then a third time very loud, and then a fourth time with a vigor evidently diminished. At this apparent dying away of the noise, the spirits of the company were immediately regained, and all was life and anecdote as before. I now ventured to inquire the cause of the disturbance.  
  
"A mere bagtelle," said Monsieur Maillard. "We are used to these things, and care really very little about them. The lunatics, every now and then, get up a howl in concert; one starting another, as is sometimes the case with a bevy of dogs at night. It occasionally happens, however, that the concerto yells are succeeded by a simultaneous effort at breaking loose, when, of course, some little danger is to be apprehended."  
  
"And how many have you in charge?"  
  
"At present we have not more than ten, altogether."  
  
"Principally females, I presume?"  
  
"Oh, no -- every one of them men, and stout fellows, too, I can tell you."  
  
"Indeed! I have always understood that the majority of lunatics were of the gentler sex."  
  
"It is generally so, but not always. Some time ago, there were about twenty-seven patients here; and, of that number, no less than eighteen were women; but, lately, matters have changed very much, as you see."  
  
"Yes -- have changed very much, as you see," here interrupted the gentleman who had broken the shins of Ma'm'selle Laplace.  
  
"Yes -- have changed very much, as you see!" chimed in the whole company at once.  
  
"Hold your tongues, every one of you!" said my host, in a great rage. Whereupon the whole company maintained a dead silence for nearly a minute. As for one lady, she obeyed Monsieur Maillard to the letter, and thrusting out her tongue, which was an excessively long one, held it very resignedly, with both hands, until the end of the entertainment.  
  
"And this gentlewoman," said I, to Monsieur Maillard, bending over and addressing him in a whisper -- "this good lady who has just spoken, and who gives us the cock-a-doodle-de-doo -- she, I presume, is harmless -- quite harmless, eh?"  
  
"Harmless!" ejaculated he, in unfeigned surprise, "why -- why, what can you mean?"  
  
"Only slightly touched?" said I, touching my head. "I take it for granted that she is not particularly not dangerously affected, eh?"  
  
"Mon dieu! what is it you imagine? This lady, my particular old friend Madame Joyeuse, is as absolutely sane as myself. She has her little eccentricities, to be sure -- but then, you know, all old women -- all very old women -- are more or less eccentric!"  
  
"To be sure," said I, -- "to be sure -- and then the rest of these ladies and gentlemen-"  
  
"Are my friends and keepers," interupted Monsieur Maillard, drawing himself up with hauteur, -- "my very good friends and assistants."  
  
"What! all of them?" I asked, -- "the women and all?"  
  
"Assuredly," he said, -- "we could not do at all without the women; they are the best lunatic nurses in the world; they have a way of their own, you know; their bright eyes have a marvellous effect; -- something like the fascination of the snake, you know."  
  
"To be sure," said I, -- "to be sure! They behave a little odd, eh? -- they are a little queer, eh? -- don't you think so?"  
  
"Odd! -- queer! -- why, do you really think so? We are not very prudish, to be sure, here in the South -- do pretty much as we please -- enjoy life, and all that sort of thing, you know-"  
  
"To be sure," said I, -- "to be sure."  
  
And then, perhaps, this Clos de Vougeot is a little heady, you know -- a little strong -- you understand, eh?"  
  
"To be sure," said I, -- "to be sure. By the bye, Monsieur, did I understand you to say that the system you have adopted, in place of the celebrated soothing system, was one of very rigorous severity?"  
  
"By no means. Our confinement is necessarily close; but the treatment -- the medical treatment, I mean -- is rather agreeable to the patients than otherwise."  
  
"And the new system is one of your own invention?"  
  
"Not altogether. Some portions of it are referable to Professor Tarr, of whom you have, necessarily, heard; and, again, there are modifications in my plan which I am happy to acknowledge as belonging of right to the celebrated Fether, with whom, if I mistake not, you have the honor of an intimate acquaintance."  
  
"I am quite ashamed to confess," I replied, "that I have never even heard the names of either gentleman before."  
  
"Good heavens!" ejaculated my host, drawing back his chair abruptly, and uplifting his hands. "I surely do not hear you aright! You did not intend to say, eh? that you had never heard either of the learned Doctor Tarr, or of the celebrated Professor Fether?"  
  
"I am forced to acknowledge my ignorance," I replied; "but the truth should be held inviolate above all things. Nevertheless, I feel humbled to the dust, not to be acquainted with the works of these, no doubt, extraordinary men. I will seek out their writings forthwith, and peruse them with deliberate care. Monsieur Maillard, you have really -- I must confess it -- you have really -- made me ashamed of myself!"  
  
And this was the fact.  
  
"Say no more, my good young friend," he said kindly, pressing my hand, -- "join me now in a glass of Sauterne."  
  
We drank. The company followed our example without stint. They chatted -- they jested -- they laughed -- they perpetrated a thousand absurdities -- the fiddles shrieked -- the drum row-de-dowed -- the trombones bellowed like so many brazen bulls of Phalaris -- and the whole scene, growing gradually worse and worse, as the wines gained the ascendancy, became at length a sort of pandemonium in petto. In the meantime, Monsieur Maillard and myself, with some bottles of Sauterne and Vougeot between us, continued our conversation at the top of the voice. A word spoken in an ordinary key stood no more chance of being heard than the voice of a fish from the bottom of Niagra Falls.  
  
"And, sir," said I, screaming in his ear, "you mentioned something before dinner about the danger incurred in the old system of soothing. How is that?"  
  
"Yes," he replied, "there was, occasionally, very great danger indeed. There is no accounting for the caprices of madmen; and, in my opinion as well as in that of Dr. Tarr and Professor Fether, it is never safe to permit them to run at large unattended. A lunatic may be 'soothed,' as it is called, for a time, but, in the end, he is very apt to become obstreperous. His cunning, too, is proverbial and great. If he has a project in view, he conceals his design with a marvellous wisdom; and the dexterity with which he counterfeits sanity, presents, to the metaphysician, one of the most singular problems in the study of mind. When a madman appears thoroughly sane, indeed, it is high time to put him in a straitjacket."  
  
"But the danger, my dear sir, of which you were speaking, in your own experience -- during your control of this house -- have you had practical reason to think liberty hazardous in the case of a lunatic?"  
  
"Here? -- in my own experience? -- why, I may say, yes. For example: -- no very long while ago, a singular circumstance occurred in this very house. The 'soothing system,' you know, was then in operation, and the patients were at large. They behaved remarkably well-especially so, any one of sense might have known that some devilish scheme was brewing from that particular fact, that the fellows behaved so remarkably well. And, sure enough, one fine morning the keepers found themselves pinioned hand and foot, and thrown into the cells, where they were attended, as if they were the lunatics, by the lunatics themselves, who had usurped the offices of the keepers."  
  
"You don't tell me so! I never heard of any thing so absurd in my life!"  
  
"Fact -- it all came to pass by means of a stupid fellow -- a lunatic -- who, by some means, had taken it into his head that he had invented a better system of government than any ever heard of before -- of lunatic government, I mean. He wished to give his invention a trial, I suppose, and so he persuaded the rest of the patients to join him in a conspiracy for the overthrow of the reigning powers."  
  
"And he really succeeded?"  
  
"No doubt of it. The keepers and kept were soon made to exchange places. Not that exactly either -- for the madmen had been free, but the keepers were shut up in cells forthwith, and treated, I am sorry to say, in a very cavalier manner."  
  
"But I presume a counter-revolution was soon effected. This condition of things could not have long existed. The country people in the neighborhood-visitors coming to see the establishment -- would have given the alarm."  
  
"There you are out. The head rebel was too cunning for that. He admitted no visitors at all -- with the exception, one day, of a very stupid-looking young gentleman of whom he had no reason to be afraid. He let him in to see the place -- just by way of variety, -- to have a little fun with him. As soon as he had gammoned him sufficiently, he let him out, and sent him about his business."  
  
"And how long, then, did the madmen reign?"  
  
"Oh, a very long time, indeed -- a month certainly -- how much longer I can't precisely say. In the meantime, the lunatics had a jolly season of it -- that you may swear. They doffed their own shabby clothes, and made free with the family wardrobe and jewels. The cellars of the chateau were well stocked with wine; and these madmen are just the devils that know how to drink it. They lived well, I can tell you."  
  
"And the treatment -- what was the particular species of treatment which the leader of the rebels put into operation?"  
  
"Why, as for that, a madman is not necessarily a fool, as I have already observed; and it is my honest opinion that his treatment was a much better treatment than that which it superseded. It was a very capital system indeed -- simple -- neat -- no trouble at all -- in fact it was delicious it was  
  
Here my host's observations were cut short by another series of yells, of the same character as those which had previously disconcerted us. This time, however, they seemed to proceed from persons rapidly approaching.  
  
"Gracious heavens!" I ejaculated -- "the lunatics have most undoubtedly broken loose."  
  
"I very much fear it is so," replied Monsieur Maillard, now becoming excessively pale. He had scarcely finished the sentence, before loud shouts and imprecations were heard beneath the windows; and, immediately afterward, it became evident that some persons outside were endeavoring to gain entrance into the room. The door was beaten with what appeared to be a sledge-hammer, and the shutters were wrenched and shaken with prodigious violence.  
  
A scene of the most terrible confusion ensued. Monsieur Maillard, to my excessive astonishment threw himself under the side-board. I had expected more resolution at his hands. The members of the orchestra, who, for the last fifteen minutes, had been seemingly too much intoxicated to do duty, now sprang all at once to their feet and to their instruments, and, scrambling upon their table, broke out, with one accord, into, "Yankee Doodle," which they performed, if not exactly in tune, at least with an energy superhuman, during the whole of the uproar.  
  
Meantime, upon the main dining-table, among the bottles and glasses, leaped the gentleman who, with such difficulty, had been restrained from leaping there before. As soon as he fairly settled himself, he commenced an oration, which, no doubt, was a very capital one, if it could only have been heard. At the same moment, the man with the teetotum predilection, set himself to spinning around the apartment, with immense energy, and with arms outstretched at right angles with his body; so that he had all the air of a tee-totum in fact, and knocked everybody down that happened to get in his way. And now, too, hearing an incredible popping and fizzing of champagne, I discovered at length, that it proceeded from the person who performed the bottle of that delicate drink during dinner. And then, again, the frog-man croaked away as if the salvation of his soul depended upon every note that he uttered. And, in the midst of all this, the continuous braying of a donkey arose over all. As for my old friend, Madame Joyeuse, I really could have wept for the poor lady, she appeared so terribly perplexed. All she did, however, was to stand up in a corner, by the fireplace, and sing out incessantly at the top of her voice, "Cock-a-doodle-de-dooooooh!"  
  
And now came the climax -- the catastrophe of the drama. As no resistance, beyond whooping and yelling and cock-a-doodling, was offered to the encroachments of the party without, the ten windows were very speedily, and almost simultaneously, broken in. But I shall never forget the emotions of wonder and horror with which I gazed, when, leaping through these windows, and down among us pele-mele, fighting, stamping, scratching, and howling, there rushed a perfect army of what I took to be Chimpanzees, Ourang-Outangs, or big black baboons of the Cape of Good Hope.  
  
I received a terrible beating -- after which I rolled under a sofa and lay still. After lying there some fifteen minutes, during which time I listened with all my ears to what was going on in the room, I came to same satisfactory denouement of this tragedy. Monsieur Maillard, it appeared, in giving me the account of the lunatic who had excited his fellows to rebellion, had been merely relating his own exploits. This gentleman had, indeed, some two or three years before, been the superintendent of the establishment, but grew crazy himself, and so became a patient. This fact was unknown to the travelling companion who introduced me. The keepers, ten in number, having been suddenly overpowered, were first well tarred, then -- carefully feathered, and then shut up in underground cells. They had been so imprisoned for more than a month, during which period Monsieur Maillard had generously allowed them not only the tar and feathers (which constituted his "system"), but some bread and abundance of water. The latter was pumped on them daily. At length, one escaping through a sewer, gave freedom to all the rest.  
  
The "soothing system," with important modifications, has been resumed at the chateau; yet I cannot help agreeing with Monsieur Maillard, that his own "treatment" was a very capital one of its kind. As he justly observed, it was "simple -- neat -- and gave no trouble at all -- not the least."  
  
I have only to add that, although I have searched every library in Europe for the works of Doctor Tarr and Professor Fether, I have, up to the present day, utterly failed in my endeavors at procuring an edition.